package com.ruoyi.project.sems.mapper;

import com.ruoyi.project.sems.domain.TSpecdevCc;

import java.util.List;

/**
 * 特种设备叉车台账Mapper接口
 *
 * @author ruoyi
 * @date 2021-07-26
 */
public interface TSpecdevCcMapper
{
    /**
     * 查询特种设备叉车台账
     *
     * @param id 特种设备叉车台账ID
     * @return 特种设备叉车台账
     */
    public TSpecdevCc selectTSpecdevCcById(Long id);

    /**
     * 查询特种设备叉车台账列表
     *
     * @param tSpecdevCc 特种设备叉车台账
     * @return 特种设备叉车台账集合
     */
//    @DataScopePlant(deptAlias = "d")
    public List<TSpecdevCc> selectTSpecdevCcList(TSpecdevCc tSpecdevCc);

    List<TSpecdevCc> selectTSpecdevCcListByYear(TSpecdevCc tSpecdevCc);
    /**
     * 新增特种设备叉车台账
     *
     * @param tSpecdevCc 特种设备叉车台账
     * @return 结果
     */
    public int insertTSpecdevCc(TSpecdevCc tSpecdevCc);

    /**
     * 修改特种设备叉车台账
     *
     * @param tSpecdevCc 特种设备叉车台账
     * @return 结果
     */
    public int updateTSpecdevCc(TSpecdevCc tSpecdevCc);

    /**
     * 删除特种设备叉车台账
     *
     * @param id 特种设备叉车台账ID
     * @return 结果
     */
    public int deleteTSpecdevCcById(Long id);

    /**
     * 批量删除特种设备叉车台账
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTSpecdevCcByIds(Long[] ids);

    void duplicateTSpecdevCc();
}
